# The FHIR-Wrapper for Transport

This package contains functions used to interact with a FHIR server. Utilities used to interact with the core [FHIR API](https://hl7.org/fhir/http.html) are contained in the `phdi.fhir.transport.http` module. Functions specific to [FHIR Bulk Data Export](http://hl7.org/fhir/uv/bulkdata/export/index.html) are contained in the `phdi.fhir.transport.export` module.